@@ -1,7 +1,7 @@
 var searchData=
 [
   ['scale_0',['scale',['../structbladerf__range.html#a1d28dec57cce925ad92342891bd71e7c',1,'bladerf_range']]],
-  ['serial_1',['serial',['../structbladerf__devinfo.html#abe126c2e73d5e14a30c3648521a9aee0',1,'bladerf_devinfo::serial()'],['../structbladerf__serial.html#abe126c2e73d5e14a30c3648521a9aee0',1,'bladerf_serial::serial()'],['../structbladerf__image.html#aaa74f66cc1ee926c3c8e871411c8fa5f',1,'bladerf_image::serial()']]],
+  ['serial_1',['serial',['../structbladerf__devinfo.html#abe126c2e73d5e14a30c3648521a9aee0',1,'bladerf_devinfo::serial'],['../structbladerf__serial.html#abe126c2e73d5e14a30c3648521a9aee0',1,'bladerf_serial::serial'],['../structbladerf__image.html#aaa74f66cc1ee926c3c8e871411c8fa5f',1,'bladerf_image::serial']]],
   ['signal_2',['signal',['../structbladerf__trigger.html#a2bea7884d40e7f7af4a9e2fa9ca39661',1,'bladerf_trigger']]],
   ['spdt_3',['spdt',['../structbladerf__quick__tune.html#a77be955e492f82e89eea9cc2d5696f85',1,'bladerf_quick_tune']]],
   ['status_4',['status',['../structbladerf__metadata.html#ade20423e91627f07e610924cb0081623',1,'bladerf_metadata']]],
